vfbLib.parsers.base.StreamReader
================================

.. currentmodule:: vfbLib.parsers.base

.. autoclass:: StreamReader
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StreamReader.__init__
      ~StreamReader.read_double
      ~StreamReader.read_doubles
      ~StreamReader.read_float
      ~StreamReader.read_floats
      ~StreamReader.read_int16
      ~StreamReader.read_int32
      ~StreamReader.read_int8
      ~StreamReader.read_str
      ~StreamReader.read_str_all
      ~StreamReader.read_uint16
      ~StreamReader.read_uint32
      ~StreamReader.read_uint8
      ~StreamReader.read_value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~StreamReader.encoding
      ~StreamReader.stream
   
   